import axios from 'axios';
import AuthResponse from '../models/AuthResponse';
import AuthRequest from '../models/AuthRequest';
import {LOGIN_METHOD} from '../../consts/urls';

class AuthAPI {
  private baseURL: string;

  constructor(baseURL: string) {
    this.baseURL = baseURL;
  }

  async auth({username, password}: AuthRequest): Promise<AuthResponse> {
    if (!username) {
      throw new Error('username is required');
    }

    if (!password) {
      throw new Error('password is required');
    }

    const {data} = await axios.post<AuthResponse>(
      `${this.baseURL}${LOGIN_METHOD}`,
      {
        username,
        password,
      },
    );

    return data;
  }
}

export default AuthAPI;
