import {
  View,
  ActivityIndicator,
  StyleProp,
  Text,
  StyleSheet,
} from 'react-native';
import {ViewStyle} from 'react-native';
import Table, {Line} from './Table';
import Status from '../../utils/Status';

interface BusListProps {
  buses: Line[];
  status: Status;
  style?: StyleProp<ViewStyle>;
}

const ERROR_MESSAGE = 'Ha ocurrido un error';
const EMPTY_MESSAGE = 'No buses available';

const BusList = ({buses, status, style}: BusListProps) => {
  if (status === Status.LOADING) {
    return (
      <View style={style}>
        <ActivityIndicator testID="LOADING" />
      </View>
    );
  }

  if (status === Status.ERROR) {
    return (
      <View style={style}>
        <Text style={styles.text}>{ERROR_MESSAGE}</Text>
      </View>
    );
  }

  if (status === Status.SUCCESS && buses.length === 0) {
    return (
      <View style={style}>
        <Text style={styles.text}>{EMPTY_MESSAGE}</Text>
      </View>
    );
  }

  return (
    <View style={style}>
      <Table data={buses} />
    </View>
  );
};

const styles = StyleSheet.create({
  text: {
    textAlign: 'center',
  },
});

export default BusList;
